prune.phylo.rank: Prune Phylogenies
Description
Prune tips of a certain taxonomic rank from an object of class phylo and obtain a new phylo object whose tips are of a higher rank.
Usage
prune.phylo.rank(phy, tax, rank = "gen", add.nb = TRUE, quiet = FALSE)
Arguments
phy
an object of class phylo.
tax
a data frame containing taxonomic information
for the tip labels in phy.
rank
a character string giving the name of a
column (= taxonomic rank) in tax to which
phy will be pruned.
Value
an object of class phylo.
See Also
addTip to add terminal nodes to a phylogeny.